@@ -7,6 +7,7 @@ from deepdriver.sdk.data_types.dataFrame import DataFrame
 from deepdriver.sdk.data_types.media import LOG_TYPE_TABLE, Media
 from deepdriver.sdk.data_types.run import Run
 from deepdriver.sdk.interface import interface
+from deepdriver import logger
 
 class Table(Media):
 
@@ -16,6 +17,17 @@ class Table(Media):
         assert_that(data).is_not_none()
         self.data = data
 
+    def __str__(self):
+        return self.data.dataframe.__str__()
+
+    def __repr__(self):
+        # return "1"
+        return self.data.dataframe.__repr__()
+
+    def _repr_html_(self):
+        # return "1"
+        return self.data.dataframe._repr_html_()
+
     def to_json(self, key_name: str) -> str:
         assert_that(key_name).is_not_none()
 
@@ -43,8 +55,9 @@ class Table(Media):
     # table내용을 json으로 변환하여 파일로 저장후 전송
     def upload_file(self, run: Run, key_name: str) -> None:
         # Table의 data인 deepdriver.dataframe으로부터 column과 data를 가져와서 json형태의 파일로 저장
-        Path(self.get_local_dir_path(run.run_id)).mkdir(parents=True, exist_ok=True)
-        local_path = self.get_local_path(run.run_id, key_name)
+        Path(self.get_local_dir_path(str(run.run_id))).mkdir(parents=True, exist_ok=True)
+        value_type = __class__.__name__
+        local_path = self.get_local_path(run.run_id, key_name, value_type )
         with open(local_path, "w") as f:
             json.dump(self.data.data, f)
 
@@ -52,10 +65,12 @@ class Table(Media):
         value_type = __class__.__name__
         root_path = self.get_root_path(run.run_id)
         path = self.get_path(key_name, value_type)
-        interface.upload_file(local_path, root_path, path, run.run_id)
+        logger.debug(f"file upload[table] : local_path=[{local_path}], root_path=[{root_path}], path=[{path}]")
+        # interface.upload_file("RUN", local_path, root_path, path, run.run_id)
+        interface.upload_file(upload_type="RUN", local_path=local_path, root_path=root_path, path=path, run_id=run.run_id, artifact_id=0, last_file_yn="Y",teamName="", expName="", artifact_name="", artifact_type="", artifact_digest="", entry_digest="", entry_list=[], file_index=0)
 
     def get_root_path(self, run_id: int) -> str:
-        return os.path.join(run_id, "media")
+        return os.path.join(str(run_id), "media")
 
     def get_local_dir_path(self, run_id: int) -> str:
         return os.path.join(".", "deepdriver", "run", self.get_root_path(run_id))
@@ -64,4 +79,4 @@ class Table(Media):
         return f"{key_name}.{value_type}.json"
 
     def get_local_path(self, run_id: int, key_name: str, value_type: str) -> str:
-        return os.path.join(self.get_local_dir_path(run_id), self.get_path(key_name, value_type))
+        return os.path.join(self.get_local_dir_path(str(run_id)), self.get_path(key_name, value_type))
