@@ -1,9 +1,14 @@
 from __future__ import annotations
 
+import os
+import sys
+
 import grpc
 import json
 from typing import Any, Dict, List, Tuple, TYPE_CHECKING
 
+from deepdriver import logger
+from deepdriver.sdk import util
 from deepdriver.sdk.interface import http_interface
 from deepdriver.sdk.interface.grpc_interface_pb2 import *
 from deepdriver.sdk.interface.grpc_interface_pb2_grpc import ResourceStub
@@ -70,7 +75,12 @@ def upload_log(run_id: int, log_step: int, item_dict: Dict[str, Any]) -> bool:
 
 CHUNK_SIZE = 1024 * 1024  # 1MB
 
-def load_file(upload_type: str, local_path: str, root_path: str, path: str, run_id: int, artifact_id: int, last_file_yn: str, teamName: str, expName: str, artifact_name: str, artifact_type: str, artifact_digest: str, entry_digest: str, entry_list: List[ArtifactEntry]) -> UploadFileRequest:
+def load_file(upload_type: str, local_path: str, root_path: str, path: str, run_id: int, artifact_id: int, last_file_yn: str, teamName: str, expName: str, artifact_name: str, artifact_type: str, artifact_digest: str, entry_digest: str, entry_list: List[ArtifactEntry], file_index: int) -> UploadFileRequest:
+    if sys.platform.startswith('win32'):
+        # 윈도우인 경우 Path Seperator를 리눅스 형식으로 강제로 변경함
+        root_path = root_path.replace("\\", "/")
+        path = path.replace("\\", "/")
+    logger.debug(f"root_path: [{root_path}], path:[{path}] ")
     yield UploadFileRequest(
         uploadType = upload_type,
         file=FileRecord(file=FileItem(
@@ -94,9 +104,15 @@ def load_file(upload_type: str, local_path: str, root_path: str, path: str, run_
         ),
     )
     with open(local_path, "rb") as file:
+        uploaded_size = 0
+        total_size = os.stat(local_path).st_size
         while True:
+
             chunk_bytes = file.read(CHUNK_SIZE)
+            uploaded_size += len(chunk_bytes)
+            util.print_progress(uploaded_size, total_size, f'Uploading: [{local_path}]', f"[{file_index + 1}/{len(entry_list)}]")
             if len(chunk_bytes) == 0: # Reached EOF
+                util.print_progress(total_size, total_size, f'Uploading: [{local_path}]',f"[{file_index + 1}/{len(entry_list)}]")  # 100%
                 return
             yield UploadFileRequest(
                 file=FileRecord(file=FileItem(
@@ -117,23 +133,31 @@ def load_file(upload_type: str, local_path: str, root_path: str, path: str, run_
                 ),
             )
 
-def upload_file( upload_type: str, local_path: str, root_path: str, path: str, run_id: int, artifact_id: int, last_file_yn: str,teamName: str, expName: str, artifact_name: str, artifact_type: str, artifact_digest: str, entry_digest: str, entry_list: List[ArtifactEntry]) -> bool:
+def upload_file( upload_type: str, local_path: str, root_path: str, path: str, run_id: int, artifact_id: int, last_file_yn: str,teamName: str, expName: str, artifact_name: str, artifact_type: str, artifact_digest: str, entry_digest: str, entry_list: List[ArtifactEntry], file_index:int) -> bool:
+    logger.debug(
+        f"upload artifact_entry : upload_type=[{upload_type}], path=[{path}], local_path=[{local_path}], root_path=[{root_path}]")
 
-    rsp: UploadFileResponse = get_stub().upload_file(load_file(upload_type, local_path, root_path, path, run_id, artifact_id, last_file_yn, teamName, expName, artifact_name, artifact_type, artifact_digest, entry_digest, entry_list))
+    rsp: UploadFileResponse = get_stub().upload_file(load_file(upload_type, local_path, root_path, path, run_id, artifact_id, last_file_yn, teamName, expName, artifact_name, artifact_type, artifact_digest, entry_digest, entry_list, file_index))
     return rsp.rsp_result.result == "success"
 
-def save_file(file_path: str, rsps) -> None:
+def save_file(file_path: str, file_index: int, total_file_count: int, file_size: int, rsps) -> None:
     with open(file_path, "wb") as file:
+        downloaded_size = 0
         for rsp in rsps:
             chunk = bytes(rsp.contents)
+            downloaded_size += len(chunk)
+            util.print_progress(downloaded_size, file_size, f'Downloading: [{file_path}]', f"[{file_index + 1}/{total_file_count}]")
             if len(chunk) == 0:
                 raise Exception("empty chunk")
             file.write(chunk)
+    util.print_progress(file_size, file_size, f'Downloading: [{file_path}]', f"[{file_index + 1}/{total_file_count}]")  # 100%
     return None
 
-def download_file(path: str, artifact_id: int, local_path: str):
+
+def download_file(path: str, artifact_id: int, local_path: str, file_index: int, total_file_count: int,
+                      file_size: int):
     # TODO 응답에 digest 값을 받아 추후 각 파일에 대한 정합성 체크시 활용한다.
-    save_file(local_path, get_stub().download_file(DownloadFileRequest(
+    save_file(local_path, file_index, total_file_count, file_size, get_stub().download_file(DownloadFileRequest(
         path=path,
         artifact_id=artifact_id,
         authorization=http_interface.get_jwt_key(),
@@ -169,7 +193,7 @@ def use_artifact(name: str, type: str, tag: str, team_name: str, exp_name: str,
             authorization=http_interface.get_jwt_key(),
         ))
     except grpc.RpcError as e:
-        print(e)
+        logger.exception("Network Error")
         return "fail" ,"network error" , -1  ,None
     return rsp.rsp_result.result , rsp.rsp_result.message, rsp.artifact_id, rsp.artifact
 
